<?php class imagingparameters extends baseobject {
	
	protected static array $fields=array(
			'name'=>validator::REQUIRED,
			'manufacturer'=>validator::REQUIRED,
			'manufacturerdatabaseid'=>array(validator::REQUIRED,validator::INTEGER),
			'currentversionid'=>array(validator::INTEGER)
	);
	
	protected static array $helpTexts=array(
			'name'=>'A unique name for this set of imaging parameters',
			'manufacturer'=>'The name of the imager manufacturer',
			'manufacturerdatabaseid'=>'The ID of this version in the imager manufacturer database',
			'currentversionid'=>'The database ID of the current version'
	);
	
}